#!/bin/sh

MACH=$1
INITRAMFS_CONTENT_DIR="`pwd`/${MACH}/content"
INITRAMFS_CONTENTS="init sound.wav"

INSTALL="install"
BUILD=""
CLEAN=""

die() {
  echo "$0: ERROR: $1 $2!"
  exit 1
}

usage() {
  cat << __EOT__
Usage: $0 <s3c64xx | s5p64xx | s5p6450 | bcm4760 | titan2> [flasher] [clean | check]
* <no option> build the initramfs contents
* check - sanity check of build
* clean - delete all build products
__EOT__
  exit 1
}

clean() {
  make MACH=${MACH} ${CLEAN} || die "Could not clean"
}

check() {
  for f in ${INITRAMFS_CONTENTS}; do
    if [ ! -s ${INITRAMFS_CONTENT_DIR}/$f ]; then
      die "$f does not exist"
    fi
  done
  echo "initramfs check passed"
}

build() {
  make MACH=${MACH} ${BUILD}   || die "Could not build initramfs contents"
  make MACH=${MACH} ${INSTALL} || die "Could not build initramfs contents"
  echo "initramfs contents built successfully"
  check
}

#######################################
# Main program starts here

n2="${XOPT_NAV2}"
if [ "$n2" = "" ]; then
  echo "Please invoke this build from the top directory"
  exit
fi

if [ -z $1 ]; then
  usage
elif [ "$2" = "flasher" ]; then
  INITRAMFS_CONTENT_DIR="`pwd`/${MACH}-flasher/content"
  INITRAMFS_CONTENTS="init"
  INSTALL="flasher-install"
  BUILD="flasher"
  CLEAN="flasher-clean"

  if   [ "$3" = "clean" ]; then
    clean
  elif [ "$3" = "check" ]; then
    check
  else
    build
  fi
    
elif [ "$2" = "clean" ]; then
  CLEAN="clean"
  clean
elif [ "$2" = "check" ]; then
  check
else
  build
fi

